aboutsummaryrefslogtreecommitdiffstats
path: root/pop3.c
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>1998-06-03 15:42:04 +0000
committerEric S. Raymond <esr@thyrsus.com>1998-06-03 15:42:04 +0000
commit7b9ce4568724dd2cf96da19f04214021b32e54e0 (patch)
tree8c86394c244a2958cfacad97633ac43fb56079b2 /pop3.c
parent628d8c1e54833d0dddde62bb01185a828891fb9a (diff)
downloadfetchmail-7b9ce4568724dd2cf96da19f04214021b32e54e0.tar.gz
fetchmail-7b9ce4568724dd2cf96da19f04214021b32e54e0.tar.bz2
fetchmail-7b9ce4568724dd2cf96da19f04214021b32e54e0.zip
POP3 should work on CompuServe now.
svn path=/trunk/; revision=1882
Diffstat (limited to 'pop3.c')
-rw-r--r--pop3.c15
1 files changed, 9 insertions, 6 deletions
diff --git a/pop3.c b/pop3.c
index 5fcdc6ab..f27b3804 100644
--- a/pop3.c
+++ b/pop3.c
@@ -534,16 +534,19 @@ static int pop3_fetch(int sock, struct query *ctl, int number, int *lenp)
* In that case, marking the seen flag is the only way to prevent the
* message from being re-fetched on subsequent runs.
*
* The line count passed is the maximum value of a twos-complement
* signed integer minus 1 (we take advantage of the fact that, according
* to all the POP RFCs, "if the number of lines requested by the
* POP3 client is greater than than the number of lines in the
* body, then the POP3 server sends the entire message.").
*/
if (ctl->keep)
gen_send(sock, "RETR %d", number);
else
- gen_send(sock, "TOP %d 2147483646", number);
+ gen_send(sock, "TOP %d 99999999", number);
if ((ok = pop3_ok(sock, buf)) != 0)
return(ok);
@@ -534,16 +534,19 @@ static int pop3_fetch(int sock, struct query *ctl, int number, int *lenp)
* message from being re-fetched on subsequent runs.
*
- * The line count passed is the maximum value of a twos-complement
- * signed integer minus 1 (we take advantage of the fact that, according
- * to all the POP RFCs, "if the number of lines requested by the
- * POP3 client is greater than than the number of lines in the
- * body, then the POP3 server sends the entire message.").
+ * We take advantage here of the fact that, according to all the
+ * POP RFCs, "if the number of lines requested by the POP3 client
+ * is greater than than the number of lines in the body, then the
+ * POP3 server sends the entire message.").
+ *
+ * The line count passed (99999999) is the maximum value CompuServe will
+ * accept; it's much lower than the natural value 2147483646 (the maximum
+ * twos-complement signed 32-bit integer minus 1)
*/
if (ctl->keep)